==> jc-1.4.0.tar.gz: gnu/java/beans/DummyAppletContext__24DummyAudioClip.h <==
// class gnu.java.beans.DummyAppletContext$DummyAudioClip

// class file dependencies
// @dep_class 3d4d52e8757521e9 gnu_java_beans_DummyAppletContext__24DummyAudioClip
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_DummyAppletContext__24DummyAudioClip_H_
#define _JC_gnu_java_beans_DummyAppletContext__24DummyAudioClip_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_refs	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_refs;
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_nonrefs	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_nonrefs;
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$refs	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$refs;
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$nonrefs	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$nonrefs;
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object;

typedef const struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vmethods	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vmethods;
typedef const struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtable	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtable;
typedef const struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype;

// Constructors
extern void _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *);

// Virtual methods
extern void _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$loop$cd8acc7e22c46b18(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *);
extern void _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$play$abb364c12ba2d201(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *);
extern void _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$stop$a0f6e77c591d5cb1(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method_info$loop$cd8acc7e22c46b18;
extern _jc_method _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method_info$play$abb364c12ba2d201;
extern _jc_method _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method_info$stop$a0f6e77c591d5cb1;
extern _jc_method _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vmethods {
	void	(*loop$cd8acc7e22c46b18)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *);
	void	(*play$abb364c12ba2d201)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *);
	void	(*stop$a0f6e77c591d5cb1)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *);
};

// Vtable
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vmethods	gnu_java_beans_DummyAppletContext__24DummyAudioClip;
};

// Vtype
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$refs {
    _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_refs	gnu_java_beans_DummyAppletContext__24DummyAudioClip;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_nonrefs	gnu_java_beans_DummyAppletContext__24DummyAudioClip;
};

// Object instance structure
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object {
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype	*vtype;
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_DummyAppletContext__24DummyAudioClip, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$class_object;

#endif	/* _JC_gnu_java_beans_DummyAppletContext__24DummyAudioClip_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/DummyAppletContext__24DummyAudioClip.h <==
// class gnu.java.beans.DummyAppletContext$DummyAudioClip

// class file dependencies
// @dep_class 3d4d52e8757521e9 gnu_java_beans_DummyAppletContext__24DummyAudioClip
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_DummyAppletContext__24DummyAudioClip_H_
#define _JC_gnu_java_beans_DummyAppletContext__24DummyAudioClip_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_refs	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_refs;
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_nonrefs	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_nonrefs;
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$refs	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$refs;
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$nonrefs	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$nonrefs;
typedef struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object;

typedef const struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vmethods	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vmethods;
typedef const struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtable	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtable;
typedef const struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype;

// Constructors
extern void _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$loop$cd8acc7e22c46b18(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$play$abb364c12ba2d201(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$stop$a0f6e77c591d5cb1(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method_info$loop$cd8acc7e22c46b18;
extern _jc_method _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method_info$play$abb364c12ba2d201;
extern _jc_method _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method_info$stop$a0f6e77c591d5cb1;
extern _jc_method _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vmethods {
	void	(*loop$cd8acc7e22c46b18)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *) _JC_JCNI_ATTR;
	void	(*play$abb364c12ba2d201)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *) _JC_JCNI_ATTR;
	void	(*stop$a0f6e77c591d5cb1)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vmethods	gnu_java_beans_DummyAppletContext__24DummyAudioClip;
};

// Vtype
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$refs {
    _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_refs	gnu_java_beans_DummyAppletContext__24DummyAudioClip;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$sub_nonrefs	gnu_java_beans_DummyAppletContext__24DummyAudioClip;
};

// Object instance structure
struct _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$object {
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype	*vtype;
	_jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$vtype _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_DummyAppletContext__24DummyAudioClip, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_DummyAppletContext__24DummyAudioClip$class_object;

#endif	/* _JC_gnu_java_beans_DummyAppletContext__24DummyAudioClip_H_ */
